@@ -1,7 +1,7 @@
 package Data::Dmp;
 
-our $DATE = '2015-04-26'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-09-18'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -161,7 +161,7 @@ Data::Dmp - Dump Perl data structures as Perl code
 
 =head1 VERSION
 
-This document describes version 0.11 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-04-26.
+This document describes version 0.12 of Data::Dmp (from Perl distribution Data-Dmp), released on 2015-09-18.
 
 =head1 SYNOPSIS
 
@@ -208,22 +208,22 @@ will keep compatibility with Perl 5.10.0.
 =head1 BENCHMARKS
 
  [1..10]:
-                      Rate    Data::Dump Data::Dumper Data::Dmp
- Data::Dump    27755+-31/s            --       -67.8%    -80.8%
- Data::Dumper  86104+-99/s  210.23+-0.5%           --    -40.4%
- Data::Dmp    144429+-62/s 420.38+-0.63% 67.74+-0.21%        --
+                     Rate    Data::Dump Data::Dumper Data::Dmp
+ Data::Dump   13874+-21/s            --       -72.1%    -78.3%
+ Data::Dumper 49689+-49/s 258.15+-0.64%           --    -22.3%
+ Data::Dmp    63974+-80/s 361.12+-0.89% 28.75+-0.21%        --
  
  [1..100]:
-                     Rate  Data::Dump Data::Dumper Data::Dmp
- Data::Dump    3487+-14/s          --       -77.0%    -81.5%
- Data::Dumper 15129+-23/s 333.8+-1.8%           --    -19.7%
- Data::Dmp    18835+-33/s 440.1+-2.3% 24.49+-0.29%        --
+                       Rate  Data::Dump    Data::Dmp Data::Dumper
+ Data::Dump   1718.1+-2.2/s          --       -80.4%       -83.3%
+ Data::Dmp       8781+-14/s 411.1+-1.1%           --       -14.6%
+ Data::Dumper   10284+-82/s 498.6+-4.8% 17.11+-0.95%           --
  
  Some mixed structure:
-                     Rate   Data::Dump    Data::Dmp Data::Dumper
- Data::Dump    8455+-15/s           --       -72.7%       -80.7%
- Data::Dmp    31023+-53/s 266.9+-0.91%           --       -29.0%
- Data::Dumper 43717+-51/s    417+-1.1% 40.92+-0.29%           --
+                       Rate    Data::Dump   Data::Dmp Data::Dumper
+ Data::Dump   4649.2+-5.8/s            --      -70.1%       -81.3%
+ Data::Dmp      15540+-77/s   234.2+-1.7%          --       -37.6%
+ Data::Dumper   24911+-33/s 435.81+-0.97% 60.3+-0.82%           --
 
 =head1 FAQ
 
@@ -250,7 +250,10 @@ dumping Perl code that can recreate circular structures.
 Of course, dumping to eval-able Perl code is slow (not to mention the cost of
 re-loading the code back to in-memory data, via eval-ing) compared to dumping to
 JSON, YAML, Sereal, or other format. So you need to decide first whether this is
-the appropriate route you want to take.
+the appropriate route you want to take. (But note that there is also
+L<Data::Dumper::Limited> and L<Data::Undump> which uses a format similar to
+Data::Dumper but lets you load the serialized data without eval-ing them, thus
+achieving the speed comparable to JSON::XS).
 
 =head1 SEE ALSO
 
